2022-09-21 Version: 1.1.24
- Automatically generate sdk tasks.

2022-09-21 Version: 1.1.23
- Automatically generate sdk tasks.

2022-09-05 Version: 1.1.22
- DSW support role chain.

2022-08-30 Version: 1.1.20
- DSW support query instance metrics .

2022-08-08 Version: 1.1.19
- Release of list instance enhancement.

2022-07-15 Version: 1.1.18
- Release of list instance enhancement.

2022-05-18 Version: 1.1.17
- Release of list instance enhancement.

2022-03-28 Version: 1.1.12
- Release of list instance enhancement.

2022-03-07 Version: 0.0.2
- Release of list instance enhancement.

2022-01-20 Version: 0.0.1
- Release of init version.

